---
url: https://www.normattiva.it/uri-res/N2Ls?urn:nir:stato:decreto.legislativo:1997-08-28;281
url_xml: https://www.normattiva.it/do/atto/caricaAKN?dataGU=19970830&codiceRedaz=097G0136&dataVigenza=20251104
dataGU: 19970830
codiceRedaz: 097G0136
dataVigenza: 20251104
---

# Definizione ed ampliamento delle attribuzioni della Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e Bolzano ed unificazione, per le materie ed i compiti di interesse comune delle regioni, delle province e dei comuni, con la Conferenza Stato - citta' ed autonomie locali.

IL PRESIDENTE DELLA REPUBBLICA

Visti gli articoli 76 e 87 della Costituzione;

Vista la legge 15 marzo 1997, n. 59, recante delega al Governo per il conferimento di funzioni e compiti amministrativi alle regioni ed enti locali, per la riforma della pubblica amministrazione e per la semplificazione amministrativa;

Visto in particolare l'articolo 9 della legge 15 marzo 1997, n. 59, che conferisce al Governo la delega ad adottare apposito decreto legislativo per la definizione e l'ampliamento delle attribuzioni della Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano e la sua unificazione, per le materie ed i compiti di interesse comune delle regioni, delle province e dei comuni, con la Conferenza Stato - citta' ed autonomie locali;

Vista l'intesa intervenuta tra il Ministero degli affari esteri ed i presidenti delle regioni e province autonome il 23 gennaio 1997, circa le modalita' del concorso delle regioni in vista della definizione della politica nazionale in sede Unione europea;

Sentita la Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano;

Sentita la Conferenza Stato - citta' ed autonomie locali allargata ai rappresentanti delle comunita' montane;

Vista la deliberazione del Consiglio dei Ministri, adottata nella riunione del 5 agosto 1997;

Sulla proposta del Presidente del Consiglio dei Ministri, di concerto con il Ministro dell'interno e con il Ministro per la funzione pubblica e gli affari regionali;

Emana

il seguente decreto legislativo:

Capo I DISPOSIZIONI GENERALI

## DISPOSIZIONI GENERALI

### Art. 1. - Ambito della disciplina

1. In attuazione dell'articolo 9 della legge 15 marzo 1997, n. 59, e ferme restando le competenze ad essa attribuite, il presente decreto disciplina le attribuzioni della Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano, di seguito denominata "Conferenza Statoregioni", e la sua unificazione, per le materie ed i compiti di interesse comune, con la Conferenza Stato - citta' ed autonomie locali.

2. Ulteriori compiti e funzioni potranno essere attribuiti contestualmente alla definitiva individuazione, ai sensi dell'articolo 3, comma 1, lettera c), della legge 15 marzo 1997, n. 59, delle procedure e degli strumenti di raccordo fra i livelli di governo.

## CONFERENZA STATO - REGIONI

### Art. 2. - C o m p i t i

1. Al fine di garantire la partecipazione delle regioni e delle province autonome di Trento e di Bolzano a tutti i processi decisionali di interesse regionale, interregionale ed infraregionale, la Conferenza Stato - regioni:

- a) promuove e sancisce intese, ai sensi dell'articolo 3;
- b) promuove e sancisce accordi di cui all'articolo 4;
- c) nel rispetto delle competenze del Comitato interministeriale per la programmazione economica, promuove il coordinamento della programmazione statale e regionale ed il raccordo di quest'ultima con l'attivita' degli enti o soggetti, anche privati, che gestiscono funzioni o servizi di pubblico interesse aventi rilevanza nell'ambito territoriale delle regioni e delle province autonome di Trento e di Bolzano;
- d) acquisisce le designazioni dei rappresentanti delle regioni e delle province autonome di Trento e di Bolzano, nei casi previsti dalla legge;
- e) assicura lo scambio di dati ed informazioni tra il Governo, le regioni e le province autonome di Trento e di Bolzano secondo le modalita' di cui all'articolo 6;
- f) fermo quanto previsto dagli statuti speciali e dalle relative norme di attuazione, determina, nei casi previsti dalla legge, i criteri di ripartizione delle risorse finanziarie che la legge assegna alle regioni e alle province autonome di Trento e di Bolzano, anche a fini di perequazione;
- g) adotta i provvedimenti che sono ad essa attribuiti dalla legge;
- h) formula inviti e proposte nei confronti di altri organi dello Stato, di enti pubblici o altri soggetti, anche privati, che gestiscono funzioni o servizi di pubblico interesse;
- i) nomina, nei casi previsti dalla legge, i responsabili di enti ed organismi che svolgono attivita' o prestano servizi strumentali all'esercizio di funzioni concorrenti tra Governo, regioni e province autonome di Trento e di Bolzano;
- l) approva gli schemi di convenzione tipo per l'utilizzo da parte dello Stato e delle regioni di uffici statali e regionali.

2. Ferma la necessita' dell'assenso del Governo, l'assenso delle regioni e delle province autonome di Trento e di Bolzano per l'adozione degli atti di cui alle lettere f), g) ed i) del comma 1 e' espresso, quando non e' raggiunta l'unanimita', dalla maggioranza dei presidenti delle regioni e delle province autonome di Trento e di Bolzano, componenti la Conferenza Stato - regioni, o da assessori da essi delegati a rappresentarli nella singola seduta.

3. La Conferenza Stato - regioni e' obbligatoriamente sentita in ordine agli schemi di disegni di legge e di decreto legislativo o di regolamento del Governo nelle materie di competenza delle regioni o delle province autonome di Trento e di Bolzano che si pronunzia entro venti giorni (( ;decorso tale termine, i provvedimenti recanti attuazione di direttive comunitarie sono emanati anche in mancanza di detto parere )). Resta fermo quanto previsto in ordine alle procedure di approvazione delle norme di attuazione degli statuti delle regioni a statuto speciale e delle province autonome di Trento e di Bolzano.

4. La Conferenza e' sentita su ogni oggetto di interesse regionale che il Presidente del Consiglio dei Ministri ritiene opportuno sottoporre al suo esame, anche su richiesta della Conferenza dei presidenti delle regioni e delle province autonome di Trento e di Bolzano.

5. Quando il Presidente del Consiglio dei Ministri dichiara che ragioni di urgenza non consentono la consultazione preventiva, la Conferenza Stato - regioni e' consultata successivamente ed il Governo tiene conto dei suoi pareri:

- a) in sede di esame parlamentare dei disegni di legge o delle leggi di conversione dei decretilegge;
- b) in sede di esame definitivo degli schemi di decreto legislativo sottoposti al parere delle commissioni parlamentari.

6. Quando il parere concerne provvedimenti gia' adottati in via definitiva, la Conferenza Stato - regioni puo' chiedere che il Governo lo valuti ai fini dell'eventuale revoca o riforma dei provvedimenti stessi.

7. La Conferenza Stato - regioni valuta gli obiettivi conseguiti ed i risultati raggiunti, con riferimento agli atti di pianificazione e di programmazione in ordine ai quali si e' pronunciata.

8. Con le modalita' di cui al comma 2 la Conferenza Stato - regioni delibera, altresi:

- a) gli indirizzi per l'uniforme applicazione dei percorsi diagnostici e terapeutici in ambito locale e le misure da adottare in caso di mancato rispetto dei protocolli relativi, ivi comprese le sanzioni a carico del sanitario che si discosti dal percorso diagnostico senza giustificato motivo, ai sensi dell'articolo 1, comma 28, della legge 23 dicembre 1996, n. 662;
- b) i protocolli di intesa dei progetti di sperimentazione gestionali individuati, ai sensi dell'articolo 9-bis del decreto legislativo 30 dicembre 1992, n. 502, e successive modificazioni ed integrazioni;
- c) gli atti di competenza degli organismi a composizione mista Stato - regioni soppressi ai sensi dell'articolo 7.

9. La Conferenza Stato - regioni esprime intesa sulla proposta, ai sensi dell'articolo 5, comma 3, del decreto legislativo 30 giugno 1993, n. 266, del Ministro della sanita' di nomina del direttore dell'Agenzia per i servizi sanitari regionali.

### Art. 3. - I n t e s e

1. Le disposizioni del presente articolo si applicano a tutti i procedimenti in cui la legislazione vigente prevede un'intesa nella Conferenza Stato - regioni. 2. Le intese si perfezionano con l'espressione dell'assenso del Governo e dei presidenti delle regioni e delle province autonome di Trento e di Bolzano. 3. Quando un'intesa espressamente prevista dalla legge non e' raggiunta entro trenta giorni dalla prima seduta della Conferenza Stato - regioni in cui l'oggetto e' posto all'ordine del giorno, il Consiglio dei Ministri provvede con deliberazione motivata. 4. In caso di motivata urgenza il Consiglio dei Ministri puo' provvedere senza l'osservanza delle disposizioni del presente articolo. I provvedimenti adottati sono sottoposti all'esame della Conferenza Statoregioni nei successivi quindici giorni. Il Consiglio dei Ministri e' tenuto ad esaminare le osservazioni della Conferenza Stato - regioni ai fini di eventuali deliberazioni successive.

### Art. 4. - Accordi tra Governo, regioni e province autonome di Trento e Bolzano

1. Governo, regioni e province autonome di Trento e di Bolzano, in attuazione del principio di leale collaborazione e nel perseguimento di obiettivi di funzionalita', economicita' ed efficacia dell'azione amministrativa, possono concludere in sede di Conferenza Statoregioni accordi, al fine di coordinare l'esercizio delle rispettive competenze e svolgere attivita' di interesse comune.

2. Gli accordi si perfezionano con l'espressione dell'assenso del Governo e dei Presidenti delle regioni e delle province autonome di Trento e di Bolzano.

### Art. 5. - Rapporti tra regioni e Unione europea

1. La Conferenza Stato - regioni, anche su richiesta delle regioni e delle province autonome di Trento e di Bolzano, si riunisce in apposita sessione almeno due volte all'anno al fine di:

- a) raccordare le linee della politica nazionale relativa all'elaborazione degli atti comunitari con le esigenze rappresentate dalle regioni e dalle province autonome di Trento e di Bolzano nelle materie di competenza di queste ultime;

2. La Conferenza Stato - regioni designa i componenti regionali in seno alla rappresentanza permanente italiana presso l'Unione europea. Su richiesta dei Presidenti delle regioni e delle province autonome di Trento e di Bolzano e col consenso del Governo, la Conferenza Statoregioni esprime parere sugli schemi di atti amministrativi dello Stato che, nelle materie di competenza delle regioni o delle province autonome di Trento e di Bolzano, danno attuazione alle direttive comunitarie ed alle sentenze della Corte di giustizia delle comunita' europee.

3. La Conferenza Stato - regioni favorisce e promuove la cooperazione tra la Cabina di regia nazionale e le regioni e le province autonome di Trento e di Bolzano, al fine della piena e tempestiva utilizzazione delle risorse comunitarie destinate all'Italia.

### Art. 6. - Scambio di dati e informazioni

1. La Conferenza Stato - regioni favorisce l'interscambio di dati ed informazioni sull'attivita' posta in essere dalle amministrazioni centrali, regionali e delle province autonome di Trento e di Bolzano.

2. La Conferenza Stato - regioni approva protocolli di intesa tra Governo, regioni e province autonome di Trento e di Bolzano, anche ai fini della costituzione di banche dati sulle rispettive attivita', accessibili sia dallo Stato che dalle regioni e dalle province autonome. Le norme tecniche ed i criteri di sicurezza per l'accesso ai dati ed alle informazioni sono stabiliti di intesa con l'Autorita' per l'informatica nella pubblica amministrazione.

3. I protocolli di intesa di cui al comma 2 prevedono, altresi', le modalita' con le quali le regioni e le province autonome si avvalgono della rete unitaria delle pubbliche amministrazioni e dei servizi di trasporto e di interoperabilita' messi a disposizione dai gestori, alle condizioni contrattuali previste ai sensi dell'articolo 15, comma 1, della legge 15 marzo 1997, n. 59.

### Art. 7. - Organismi a composizione mista

1. Ferma restando ogni altra competenza dell'amministrazione centrale dello Stato, gli organismi a composizione mista Stato - regioni di cui all'allegato A sono soppressi e le relative funzioni sono esercitate dalla Conferenza Stato - regioni.

2. La Conferenza Stato - regioni puo' istituire gruppi di lavoro o comitati, con la partecipazione di rappresentanti delle regioni, delle province autonome di Trento e di Bolzano e delle amministrazioni interessate, con funzioni istruttorie, di raccordo, collaborazione o concorso alla attivita' della Conferenza stessa.

## CONFERENZA UNIFICATA

### Art. 8. - Conferenza Stato - citta' ed autonomie locali e Conferenza unificata

1. La Conferenza Stato - citta' ed autonomie locali e' unificata per le materie ed i compiti di interesse comune delle regioni, delle province, dei comuni e delle comunita' montane, con la Conferenza Stato - regioni.

2. La Conferenza Stato - citta' ed autonomie locali e' presieduta dal Presidente del Consiglio dei Ministri o, per sua delega, dal Ministro dell'interno o dal Ministro per gli affari regionali (( nella materia di rispettiva competenza )); ne fanno parte altresi' il Ministro del tesoro e del bilancio e della programmazione economica, il Ministro delle finanze, il Ministro dei lavori pubblici, il Ministro della sanita', il presidente dell'Associazione nazionale dei comuni d'Italia - ANCI, il presidente dell'Unione province d'Italia - UPI ed il presidente dell'Unione nazionale comuni, comunita' ed enti montani - UNCEM. Ne fanno parte inoltre quattordici sindaci designati dall'ANCI e sei presidenti di provincia designati dall'UPI. Dei quattordici sindaci designati dall'ANCI cinque rappresentano le citta' individuate dall'articolo 17 della legge 8 giugno 1990, n. 142. Alle riunioni possono essere invitati altri membri del Governo, nonche' rappresentanti di amministrazioni statali, locali o di enti pubblici.

3. La Conferenza Stato - citta' ed autonomie locali e' convocata almeno ogni tre mesi, e comunque in tutti i casi il presidente ne ravvisi la necessita' o qualora ne faccia richiesta il presidente dell'ANCI, dell'UPI o dell'UNCEM.

4. La Conferenza unificata di cui al comma 1 e' convocata dal Presidente del Consiglio dei Ministri. Le sedute sono presiedute dal Presidente del Consiglio dei Ministri o, su sua delega, dal Ministro per gli affari regionali o, se tale incarico non e' conferito, dal Ministro dell'interno.

### Art. 9. - F u n z i o n i

1. La Conferenza unificata assume deliberazioni, promuove e sancisce intese ed accordi, esprime pareri, designa rappresentanti in relazione alle materie ed ai compiti di interesse comune alle regioni, alle province, ai comuni e alle comunita' montane.

2. La Conferenza unificata e' comunque competente in tutti i casi in cui regioni, province, comuni e comunita' montane ovvero la Conferenza Stato - regioni e la Conferenza Stato - citta' ed autonomie locali debbano esprimersi su un medesimo oggetto. In particolare la Conferenza unificata:

- a) esprime parere: 1) sul disegno di legge finanziaria e sui disegni di legge collegati; 2) sul documento di programmazione economica e finanziaria; 3) sugli schemi di decreto legislativo adottati in base all'articolo 1 della legge 15 marzo 1997, n. 59;
- b) promuove e sancisce intese tra Governo, regioni, province, comuni e comunita' montane. Nel caso di mancata intesa o di urgenza si applicano le disposizioni di cui all'articolo 3, commi 3 e 4;
- c) promuove e sancisce accordi tra Governo, regioni, province, comuni e comunita' montane, al fine di coordinare l'esercizio delle rispettive competenze e svolgere in collaborazione attivita' di interesse comune;
- d) acquisisce le designazioni dei rappresentanti delle autonomie locali indicati, rispettivamente, dai presidenti delle regioni e province autonome di Trento e di Bolzano, dall'ANCI, dall'UPI e dall'UNCEM nei casi previsti dalla legge;
- e) assicura lo scambio di dati e informazioni tra Governo, regioni, province, comuni e comunita' montane nei casi di sua competenza, anche attraverso l'approvazione di protocolli di intesa tra le amministrazioni centrali e locali secondo le modalita' di cui all'articolo 6;
- f) e' consultata sulle linee generali delle politiche del personale pubblico e sui processi di riorganizzazione e mobilita' del personale connessi al conferimento di funzioni e compiti alle regioni ed agli enti locali;
- g) esprime gli indirizzi per l'attivita' dell'Agenzia per i servizi sanitari regionali.

3. Il Presidente del Consiglio dei Ministri puo' sottoporre alla Conferenza unificata, anche su richiesta delle autonomie regionali e locali, ogni altro oggetto di preminente interesse comune delle regioni, delle province, dei comuni e delle comunita' montane.

4. Ferma restando la necessita' dell'assenso del Governo per l'adozione delle deliberazioni di competenza della Conferenza unificata, l'assenso delle regioni, delle province, dei comuni e delle comunita' montane e' assunto con il consenso distinto dei membri dei due gruppi delle autonomie che compongono, rispettivamente, la Conferenza Stato - regioni e la Conferenza Stato - citta' ed autonomie locali. L'assenso e' espresso di regola all'unanimita' dei membri dei due predetti gruppi. Ove questa non sia raggiunta l'assenso e' espresso dalla maggioranza dei rappresentanti di ciascuno dei due gruppi.

5. La Conferenza Stato - citta' ed autonomie locali ha compiti di:

- a) coordinamento nei rapporti tra lo Stato e le autonomie locali;
- b) studio, informazione e confronto nelle problematiche connesse agli indirizzi di politica generale che possono incidere sulle funzioni proprie o delegate di province e comuni e comunita' montane.

6. La Conferenza Stato - citta' ed autonomie locali, in particolare, e' sede di discussione ed esame:

- a) dei problemi relativi all'ordinamento ed al funzionamento degli enti locali, compresi gli aspetti relativi alle politiche finanziarie e di bilancio, alle risorse umane e strumentali, nonche' delle iniziative legislative e degli atti generali di governo a cio' attinenti;
- b) dei problemi relativi alle attivita' di gestione ed erogazione dei servizi pubblici;
- c) di ogni altro problema connesso con gli scopi di cui al presente comma che venga sottoposto, anche su richiesta del Presidente dell'ANCI, dell'UPI e dell'UNCEM, al parere della Conferenza dal Presidente del Consiglio dei Ministri o dal Presidente delegato.

7. La Conferenza Stato - citta' ed autonomie locali ha inoltre il compito di favorire:

- a) l'informazione e le iniziative per il miglioramento dell'efficienza dei servizi pubblici locali;
- b) la promozione di accordi o contratti di programma ai sensi dell'articolo 12 della legge 23 dicembre 1992, n. 498;
- c) le attivita' relative alla organizzazione di manifestazioni che coinvolgono piu' comuni o province da celebrare in ambito nazionale.

### Art. 10. - Segreteria

1. L'attivita' istruttoria e di supporto al funzionamento della Conferenza unificata sono svolte congiuntamente dalla segreteria della Conferenza Statoregioni e dalla segreteria della Conferenza Stato - citta' ed autonomie locali.

2. La segreteria della Conferenza Stato - regioni opera alle dirette dipendenze e secondo gli indirizzi del presidente della Conferenza stessa. Ad essa e' assegnato personale dello Stato e, fino alla meta' dei posti in organico, da personale delle regioni e delle province autonome di Trento e di Bolzano, il cui trattamento economico rimane a carico delle amministrazioni di appartenenza.

3. Con decreto del Presidente del Consiglio dei Ministri, su proposta del Ministro per gli affari regionali, sono disciplinati l'organizzazione ed il funzionamento della segreteria della Conferenza Stato - regioni ed individuati gli uffici di livello dirigenziale.

4. Per lo svolgimento dei propri compiti, la Conferenza Stato - citta' ed autonomie locali si avvale di una segreteria collocata presso la Presidenza del Consiglio dei Ministri.

5. La composizione della segreteria della Conferenza Stato - citta' ed autonomie locali e' stabilita con successivo provvedimento di organizzazione. Con il medesimo provvedimento potra' essere previsto che fino alla meta' dei posti in organico possa essere coperto da personale delle province, dei comuni e delle comunita' montane, il cui trattamento economico rimane a carico delle amministrazioni di appartenenza. I restanti posti in organico sono coperti con personale della Presidenza del Consiglio dei Ministri. Puo' essere altresi' assegnato alla segreteria anche personale del Ministero dell'interno.

